@@ -3,6 +3,7 @@
 
 #include <glib-object.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
+#include <libgnomevfs/gnome-vfs-file-size.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "eog-transform.h"
 
@@ -81,6 +82,7 @@ gboolean            eog_image_is_animation                    (EogImage *img);
 GdkPixbuf*          eog_image_get_pixbuf                      (EogImage *img);
 GdkPixbuf*          eog_image_get_pixbuf_thumbnail            (EogImage *img);
 void                eog_image_get_size                        (EogImage *img, int *width, int *height);
+GnomeVFSFileSize    eog_image_get_bytes                       (EogImage *img);
 gboolean            eog_image_is_modified                     (EogImage *img);
 gchar*              eog_image_get_caption                     (EogImage *img);
 const gchar*        eog_image_get_collate_key                 (EogImage *img);
